@@ -1,25 +1,12 @@
 /*
-  Copyright (C) 2013 Sérgio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2013 Sérgio Martins <iamsergio@gmail.com>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "incidencechanger_p.h"
 #include "utils_p.h"
-#include <kcalendarcore/incidence.h>
+#include <KCalendarCore/Incidence>
 #include "akonadicalendar_debug.h"
 #include <item.h>
 #include <itemcreatejob.h>
@@ -32,12 +19,12 @@ using namespace Akonadi;
 
 void Change::emitUserDialogClosedAfterChange(Akonadi::ITIPHandlerHelper::SendResult status)
 {
-    emit dialogClosedAfterChange(id, status);
+    Q_EMIT dialogClosedAfterChange(id, status);
 }
 
 void Change::emitUserDialogClosedBeforeChange(Akonadi::ITIPHandlerHelper::SendResult status)
 {
-    emit dialogClosedBeforeChange(id, status);
+    Q_EMIT dialogClosedBeforeChange(id, status);
 }
 
 void IncidenceChanger::Private::loadCollections()
